summaryrefslogtreecommitdiff
path: root/mac/inc
diff options
context:
space:
mode:
authorKim F. Storm <storm@cua.dk>2001-11-16 13:19:19 +0000
committerKim F. Storm <storm@cua.dk>2001-11-16 13:19:19 +0000
commit4fb4f1ddc9a98922908fea2a6ba7b0c0a39ab7cf (patch)
tree7001bdfd49d59e414acdd217fefa19a013cfd8fb /mac/inc
parent09349bc9037fdc87c3847e60c21186cd64f91f26 (diff)
downloademacs-4fb4f1ddc9a98922908fea2a6ba7b0c0a39ab7cf.tar.gz
Fringe cleanup.
Comment fixes. Use renamed symbols. (fringes_extra): Renamed from flags_areas_extra. (FRAME_FRINGE_BITMAP_WIDTH): Renamed from FRAME_FLAGS_BITMAP_WIDTH. (FRAME_FRINGE_BITMAP_HEIGHT): Renamed from FRAME_FLAGS_BITMAP_HEIGHT. (FRAME_X_FRINGE_COLS): Renamed from FRAME_X_FLAGS_AREA_COLS. (FRAME_X_FRINGE_WIDTH): Renamed from FRAME_X_FLAGS_AREA_WIDTH. (FRAME_X_LEFT_FRINGE_WIDTH): Renamed from FRAME_X_LEFT_FLAGS_AREA_WIDTH. (FRAME_X_RIGHT_FRINGE_WIDTH): Renamed from FRAME_X_RIGHT_FLAGS_AREA_WIDTH.
Diffstat (limited to 'mac/inc')
-rw-r--r--mac/inc/macterm.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/mac/inc/macterm.h b/mac/inc/macterm.h
index 7145e57fa71..f105dcab8cd 100644
--- a/mac/inc/macterm.h
+++ b/mac/inc/macterm.h
@@ -358,7 +358,7 @@ struct mac_output {
/* The extra width currently allotted for the areas in which
truncation marks, continuation marks, and overlay arrows are
displayed. */
- int flags_areas_extra;
+ int fringes_extra;
/* This is the gravity value for the specified window position. */
int win_gravity;
@@ -451,38 +451,38 @@ typedef struct mac_output mac_output;
#define FRAME_X_IMAGE_CACHE(F) FRAME_MAC_DISPLAY_INFO ((F))->image_cache
/* Pixel width of the bitmaps drawn to indicate truncation,
continuation etc. */
#define FRAME_FLAGS_BITMAP_WIDTH(f) 8
#define FRAME_FLAGS_BITMAP_HEIGHT(f) 8
/* Total width of areas reserved for drawing truncation bitmaps,
continuation bitmaps and alike. The width is in canonical char
units of the frame. This must currently be the case because window
sizes aren't pixel values. If it weren't the case, we wouldn't be
able to split windows horizontally nicely. */
-#define FRAME_X_FLAGS_AREA_COLS(F) \
- ((2 * FRAME_FLAGS_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1) \
+#define FRAME_X_FRINGE_COLS(F) \
+ ((2 * FRAME_FRINGE_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1) \
/ CANON_X_UNIT ((F)))
-/* Total width of flags areas in pixels. */
+/* Total width of fringes in pixels. */
-#define FRAME_X_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_COLS ((F)) * CANON_X_UNIT ((F)))
+#define FRAME_X_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_COLS ((F)) * CANON_X_UNIT ((F)))
-/* Pixel-width of the left flags area. */
+/* Pixel-width of the left fringe. */
-#define FRAME_X_LEFT_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+#define FRAME_X_LEFT_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_WIDTH (F) / 2)
-/* Pixel-width of the right flags area. Note that we are doing
+/* Pixel-width of the right fringe. Note that we are doing
integer arithmetic here, so don't loose a pixel if the total
width is an odd number. */
-#define FRAME_X_RIGHT_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_WIDTH (F) - FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+#define FRAME_X_RIGHT_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_WIDTH (F) - FRAME_X_FRINGE_WIDTH (F) / 2)
@@ -632,7 +632,7 @@ struct scroll_bar {
#define CHAR_TO_PIXEL_WIDTH(f, width) \
(CHAR_TO_PIXEL_COL (f, width) \
+ (f)->output_data.mac->vertical_scroll_bar_extra \
- + (f)->output_data.mac->flags_areas_extra \
+ + (f)->output_data.mac->fringes_extra \
+ (f)->output_data.mac->internal_border_width)
#define CHAR_TO_PIXEL_HEIGHT(f, height) \
(CHAR_TO_PIXEL_ROW (f, height) \
@@ -653,7 +653,7 @@ struct scroll_bar {
#define PIXEL_TO_CHAR_WIDTH(f, width) \
(PIXEL_TO_CHAR_COL (f, ((width) \
- (f)->output_data.mac->internal_border_width \
- - (f)->output_data.mac->flags_areas_extra \
+ - (f)->output_data.mac->fringes_extra \
- (f)->output_data.mac->vertical_scroll_bar_extra)))
#define PIXEL_TO_CHAR_HEIGHT(f, height) \
(PIXEL_TO_CHAR_ROW (f, ((height) \
@@ -451,38 +451,38 @@ typedef struct mac_output mac_output;
#define FRAME_X_IMAGE_CACHE(F) FRAME_MAC_DISPLAY_INFO ((F))->image_cache
-/* Pixel width of the bitmaps drawn to indicate truncation,
+/* Pixel width of the fringe bitmaps drawn to indicate truncation,
continuation etc. */
@@ -451,38 +451,38 @@ typedef struct mac_output mac_output;
continuation etc. */
-#define FRAME_FLAGS_BITMAP_WIDTH(f) 8
-#define FRAME_FLAGS_BITMAP_HEIGHT(f) 8
+#define FRAME_FRINGE_BITMAP_WIDTH(f) 8
+#define FRAME_FRINGE_BITMAP_HEIGHT(f) 8
-/* Total width of areas reserved for drawing truncation bitmaps,
+/* Total width of fringes reserved for drawing truncation bitmaps,
continuation bitmaps and alike. The width is in canonical char
units of the frame. This must currently be the case because window